"use strict";

var _core = require("babel-runtime/core-js")["default"];

exports.__esModule = true;

var _require = require("./util");

var request = _require.request;

var link = require("parse-link-header");

// Get raw API pages.
var pages = function (opts) {
  return request(opts).flatMap(function (response) {
    // Default to single space to force `link` to return an object.
    // Empty string or `null` would result in `null`.
    var next = link(response.headers.link || " ").next;

    return [response].concat(!next ? [] : pages(_core.Object.assign({}, opts, { url: next.url })));
  });
};

// Get raw API GitHub user repositories.
var rawRepos = function (_ref) {
  var user = _ref.user;
  var token = _ref.token;
  var _ref$prefix = _ref.prefix;
  var prefix = _ref$prefix === undefined ? "https://api.github.com" : _ref$prefix;
  var _ref$agent = _ref.agent;
  var agent = _ref$agent === undefined ? "gogs-migrate" : _ref$agent;
  return pages({
    url: "" + prefix + "/users/" + user + "/repos",
    headers: { "user-agent": agent },
    auth: token && { user: user, pass: token },
    json: true
  }).flatten().flatMap(function (response) {
    return response.body;
  });
};

exports.rawRepos = rawRepos;
// Extract Gogs formatted data from a repository.
var parse = function (repo) {
  return {
    url: repo.clone_url,
    name: repo.name,
    desc: repo.description,
    fork: repo.fork,
    "private": repo["private"]
  };
};

exports.parse = parse;
// Get repositories in Gogs format.
var repos = function (opts) {
  return rawRepos(opts).map(parse);
};
exports.repos = repos;